@@ -26,15 +26,18 @@ public:
     quint16 setCliPort(quint16 newCliPort);
     QString setUsername(QString newUsername);
     QString setPassword(QString newPassword);
+    //quint16 setScreensaverIsInhibited(quint16 newScreensaverIsInhibited);
+    bool    setScreensaverIsInhibited(bool newScreensaverIsInhibited);
 
     QString username() const {return(username_i);}
     QString password() const {return(password_i);}
     const QString ipAddress() const {return(ipAddress_i);}
     quint16 httpPort() const {return(httpPort_i);}
     quint16 cliPort() const {return(cliPort_i);}
+    bool    screensaverIsInhibited() const {return(screensaverIsInhibited_i);}
 
-    bool load();
-    bool save();
+    //bool load();
+    //bool save();
     bool clone(const UserSettings &other);
     const bool operator==(const UserSettings &rhs) const;
     const bool operator!=(const UserSettings &rhs) const;
@@ -50,7 +53,7 @@ private:
     QString ipAddress_i;
     quint16 httpPort_i;
     quint16 cliPort_i;
-
+    bool    screensaverIsInhibited_i;
 };
 
 #endif // USERSETTINGS_H
